@@ -1,10 +1,10 @@
 package Alien::cares;
 use 5.012;
 
-our $VERSION = "1.1.1.2";
+our $VERSION = "1.1.1.3";
 
 use XS::Loader;
 
-XS::Loader::bootstrap();
+XS::Loader::load_noboot();
 
 1;
